# Common errors

## During package load

Errors that may occur when executing `import iesopt`.

- _"Exception: no version of Julia is compatible with =x.y.z - perhaps you need to update JuliaUp"_: Open a terminal and execute `juliaup update`. If it still reports the same error afterwards, checkout the specific version that it fails to find, and manually install that.
